@@ -797,9 +797,10 @@ ggv_postscript_view_get_ps(GgvPostScriptView *ps_view, gint *active_rows)
 static void
 ggv_postscript_view_print(GgvPostScriptView *ps_view, gchar *ps)
 {
-	gchar **argv = NULL;
-	gint print_in = -1;
+	gchar **argv;
+	gint print_in;
 
+	argv = g_strsplit(ggv_print_cmd, " ", 0);
 	if((NULL == ggv_print_cmd) ||
 	   ((argv = g_strsplit(ggv_print_cmd, " ", 0)) == NULL) ||
 	   (argv[0] == NULL) ||
@@ -828,7 +829,7 @@ ggv_postscript_view_print(GgvPostScriptView *ps_view, gchar *ps)
 		write(print_in, ps, strlen(ps));
 		close(print_in);
 	}
-	if(NULL != argv)
+	if(NULL == argv)
 		g_strfreev(argv);
 }
 
@@ -900,6 +901,7 @@ verb_FileSaveMarked(BonoboUIComponent *uic, gpointer data, const char *cname)
 
 	if(doc != NULL) {
 		GtkWidget *chooser;
+        GtkFileFilter *ps_filter, *all_filter;
 
 		chooser = gtk_file_chooser_dialog_new(_("Select a file to save pages as"),
 											  GTK_WINDOW(gtk_widget_get_toplevel(ps_view->priv->gs)),
@@ -907,6 +909,21 @@ verb_FileSaveMarked(BonoboUIComponent *uic, gpointer data, const char *cname)
 											  GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
 											  GTK_STOCK_SAVE, GTK_RESPONSE_OK,
 											  NULL);
+        /* first: Postscript doc filter */
+		ps_filter = gtk_file_filter_new ();
+		gtk_file_filter_set_name (ps_filter, _("PostScript Documents"));
+		gtk_file_filter_add_mime_type (ps_filter, "application/postscript");
+		gtk_file_chooser_add_filter (GTK_FILE_CHOOSER (chooser), ps_filter);
+
+        /* second: all files filter */
+        all_filter = gtk_file_filter_new ();
+		gtk_file_filter_set_name (all_filter, _("All Files"));
+		gtk_file_filter_add_pattern (all_filter, "*.*");
+		gtk_file_chooser_add_filter (GTK_FILE_CHOOSER (chooser), all_filter);
+
+        /* postscript is default */
+        gtk_file_chooser_set_filter (GTK_FILE_CHOOSER (chooser), ps_filter);
+
 		add_dialog_to_view(ps_view, GTK_WIDGET(chooser));
 		if(ps_view->priv->owner != NULL) {
 			bonobo_control_set_transient_for(ps_view->priv->owner,
