@@ -38,8 +38,18 @@ ggv_prefs_load()
                 g_free(ggv_print_cmd);
         ggv_print_cmd = gconf_client_get_string(gconf_client, "/apps/ggv/printing/command",
                                                 NULL);
-        if(!ggv_print_cmd)
+        if(ggv_print_cmd == NULL || ggv_print_cmd[0] == '\0') {
                 ggv_print_cmd = g_strdup(LPR_PATH);
+                
+                if (ggv_print_cmd == NULL || ggv_print_cmd [0] == '\0') {
+                        /* For Solaris, lpr is probably not in PATH */
+                        const char *lpr_cmd = "/usr/ucb/lpr";
+                        if (g_file_test (lpr_cmd, G_FILE_TEST_IS_EXECUTABLE)) {
+                                g_free (ggv_print_cmd);
+                                ggv_print_cmd = g_strdup (lpr_cmd);
+                        }
+                }
+        }
 
         ggv_unit_index = gconf_client_get_int(gconf_client, "/apps/ggv/coordinates/units",
                                               NULL);
