@@ -323,7 +323,8 @@ verb_FileOpen(BonoboUIComponent *uic, gpointer data, const char *cname)
         GgvWindow *win = GGV_WINDOW(data);
 	GtkWidget *chooser;
         GtkWidget *newwin;
-
+        GtkFileFilter *ps_filter, *all_filter;
+        
 	chooser = gtk_file_chooser_dialog_new(_("Select a PostScript document"),
 					      GTK_WINDOW(win),
 					      GTK_FILE_CHOOSER_ACTION_OPEN,
@@ -333,6 +334,21 @@ verb_FileOpen(BonoboUIComponent *uic, gpointer data, const char *cname)
         gtk_file_chooser_set_select_multiple(GTK_FILE_CHOOSER(chooser), TRUE);
 	gtk_dialog_set_default_response(GTK_DIALOG(chooser), GTK_RESPONSE_OK);
 
+        /* first: Postscript doc filter */
+	ps_filter = gtk_file_filter_new ();
+	gtk_file_filter_set_name (ps_filter, _("PostScript Documents"));
+	gtk_file_filter_add_mime_type (ps_filter, "application/postscript");
+	gtk_file_chooser_add_filter (chooser, ps_filter);
+
+        /* second: all files filter */
+        all_filter = gtk_file_filter_new ();
+	gtk_file_filter_set_name (all_filter, _("All Files"));
+	gtk_file_filter_add_pattern (all_filter, "*.*");
+	gtk_file_chooser_add_filter (chooser, all_filter);
+
+        /* postscript is default */
+        gtk_file_chooser_set_filter (chooser, ps_filter);
+	
 #if 0
         /* this causes unexplained crashes! */
 	if (win->filename)
@@ -408,8 +424,7 @@ static void
 verb_FileClose(BonoboUIComponent *uic, gpointer data, const char *cname)
 {
         GgvWindow *win = GGV_WINDOW(data);
-
-        ggv_window_close(win);
+        ggv_window_close(win);	
         if (window_list == NULL)
                 bonobo_main_quit();
 }
@@ -973,9 +988,13 @@ ggv_add_open_button (GgvWindow *win, BonoboUIComponent *ui_component,
         EggRecentViewGtk *view;
         EggRecentModel *model;
         GtkWidget *button;
-                                                                                                                             
+        GtkTooltips *tooltips;
+
+        tooltips = gtk_tooltips_new ();
+                                                                                                                            
         button = gtk_toggle_button_new ();
         gtk_button_set_relief (GTK_BUTTON (button), GTK_RELIEF_NONE);
+	gtk_tooltips_set_tip (tooltips,button, _("Open recent files"), NULL);
                                                                                                                              
         gtk_container_add (GTK_CONTAINER (button),
                            gtk_arrow_new (GTK_ARROW_DOWN, GTK_SHADOW_OUT));
@@ -1186,13 +1205,15 @@ ggv_window_load(GgvWindow *win, const gchar *filename)
         gchar *title, *unescaped, *utf8_title, *_filename;
         GnomeVFSFileInfo info;
 	Bonobo_UIContainer container;
+        gint i;
+        gchar *path_end;
 
         g_return_val_if_fail(win != NULL, FALSE);
         g_return_val_if_fail(GGV_IS_WINDOW(win), FALSE);
         g_return_val_if_fail(filename != NULL, FALSE);
 
         ggv_window_set_watch_file(win, FALSE);
-
+	
 	if (GNOME_VFS_OK == gnome_vfs_get_file_info(filename, &info, 
                                                     GNOME_VFS_FILE_INFO_GET_MIME_TYPE |
                                                     GNOME_VFS_FILE_INFO_FOLLOW_LINKS)) {
@@ -1230,8 +1251,15 @@ ggv_window_load(GgvWindow *win, const gchar *filename)
                 g_free(win->filename);
         win->filename = _filename;
 
-        unescaped = gnome_vfs_unescape_string_for_display(win->filename);
-        title = g_strconcat(_("GGV: "), unescaped, NULL);
+        for(i = strlen(win->filename) - 1;
+            (i >= 0) && (win->filename[i] != '/'); i--)
+                ;
+        if(win->filename[i] == '/')
+                path_end = &win->filename[i+1];
+        else
+                path_end = win->filename;
+        unescaped = gnome_vfs_unescape_string_for_display(path_end);           
+        title = g_strconcat(unescaped, _(" - GGV"), NULL);
         g_free(unescaped);
         utf8_title = g_locale_to_utf8(title, -1, NULL, NULL, NULL);
         g_free(title);
