@@ -1907,9 +1907,10 @@ gtk_gs_goto_page (GtkGS *gs, gint page)
                    gs->doc->pages[page].orientation != gs->real_orientation) {
                         gs->real_orientation = gs->doc->pages[page].orientation;
                         gs->changed = TRUE;
-                        gtk_widget_queue_resize(GTK_WIDGET(gs));
                 }
 
+                gtk_gs_set_page_size(gs, -1, page);
+
                 gs->changed = FALSE;
 
                 if (is_interpreter_ready (gs)) {
